Module cli

Module cli 

Structs

InstallArgs
Configuration for install.
LocateArgs
Options for locating a toolchain.
RemoveArgs
Configuration for remove.
RunArgs
Configuration for run.
UseArgs

Enums

ArmToolchainCmd
Arm Toolchain Manager is a tool for installing and managing the LLVM-based ARM embedded toolchain.
CliError

Constants

STYLES

Statics

PROGRESS_STYLE_DELETE
PROGRESS_STYLE_DELETE_SPINNER
PROGRESS_STYLE_DL
PROGRESS_STYLE_DL_MSG
PROGRESS_STYLE_EXTRACT
PROGRESS_STYLE_EXTRACT_SPINNER
PROGRESS_STYLE_VERIFY

Functions

confirm_install
ctrl_c_cancel
Create a cancel token that will trigger when Ctrl-C (SIGINT on Unix) is pressed.
install
Remove a toolchain to the system.
install_with_progress_bar
list
Print a list of all toolchains to stdio.
locate
Locate a toolchain’s path and print it to stdio.
purge_cache
Purge the download cache and print results to stdio.
remove
Remove a toolchain from the system.
run
Run a CLI tool with the toolchain in the PATH.
use_cmd