pub enum ArmToolchainCmd {
Install(InstallArgs),
Remove(RemoveArgs),
Run(RunArgs),
Locate(LocateArgs),
Use(UseArgs),
List,
PurgeCache,
}Expand description
Arm Toolchain Manager is a tool for installing and managing the LLVM-based ARM embedded toolchain.
See also: atrun
Variants
Install(InstallArgs)
Install, verify, and extract a version of the ARM Embedded Toolchain.
Toolchains are installed per-user in a platform-specific data directory. If there is another toolchain already installed, that toolchain will still be used after installing this one.
If you would like to enable a toolchain you’ve installed, or install and enable
a toolchain all at once, invoke the use command instead.
Remove(RemoveArgs)
Uninstall a single toolchain version, or all versions.
When a toolchain is uninstalled, it is unset as the current toolchain and deleted from the toolchains directory and download cache.
If “all” is specified as the version to remove, every toolchain on the system will be uninstalled.
Run(RunArgs)
Run a command with the active toolchain added to the PATH.
Unless you specify --no-cross-env, the TARGET_CC and TARGET_AR environment
variables will also be set to clang and llvm-ar respectively. These will resolve
to the toolchain’s versions of clang and llvm-ar.
An alias for this command is the external atrun executable. You may need to pass an
extra -- to the command if some flags look like ones arm-toolchain would accept.
Locate(LocateArgs)
Print the path of the active toolchain.
Use(UseArgs)
Active a desired version of the ARM Embedded Toolchain, downloading it if necessary.
List
List all installed toolchain versions and the current active version.
PurgeCache
Delete the cache which stores incomplete downloads.
Implementations