pub struct InstalledToolchain {
pub path: PathBuf,
}Expand description
An ARM toolchain that may be installed on the current system.
Fields
path: PathBufImplementations
Sourceimpl InstalledToolchain
impl InstalledToolchain
pub fn new(path: PathBuf) -> Self
pub async fn check_installed(&self) -> Result<(), ToolchainError>
Sourcepub fn host_bin_dir(&self) -> PathBuf
pub fn host_bin_dir(&self) -> PathBuf
Returns the path to a directory containing binaries that run on the host.
This directory typically contains the compiler (clang) and support executables
like llvm-objcopy.
Sourcepub fn lib_dir(&self) -> PathBuf
pub fn lib_dir(&self) -> PathBuf
Returns the path to a directory containing support libraries.
This directory typically contains libLTO.dylib.
Sourcepub fn multilib_dir(&self) -> PathBuf
pub fn multilib_dir(&self) -> PathBuf
Returns the path to a directory containing a multilib.
The path returned is equivalent to self.lib_dir().join("clang-runtimes").
This directory contains the libraries for all supported targets as well as a
multilib.yaml file which describes which sub-directories they are located in.
Sourcepub fn target_lib_dir(&self, triple: &str, variant: &str) -> PathBuf
pub fn target_lib_dir(&self, triple: &str, variant: &str) -> PathBuf
Returns the path to a directory containing static libraries for the given target.
Targets are considered to have both a triple and a variant. Non-library files such as linker scripts or objects may be included in this directory.
Example triples:
arm-none-eabiaarch64-none-elf
Example variants:
armv7a_soft_nofp(ARMv7-A, soft float ABI, no FPU)armv7m_soft_vfpv3_d16_exn_rtti(ARMv7-M, soft float ABI, vfpv3 FPU, 16 float registers, with RTTI)armv7a_soft_vfpv3_d16_exn_rtti(ARMv7-M, soft float ABI, vfpv3 FPU, 16 float registers, with RTTI)
Sourcepub fn target_include_dirs(&self, triple: &str, variant: &str) -> Vec<PathBuf>
pub fn target_include_dirs(&self, triple: &str, variant: &str) -> Vec<PathBuf>
Returns the paths to header directories for the given target.
Targets are considered to have both a triple and a variant.
See Self::target_lib_dir for example triples and variants.