pub struct ToolchainClient { /* private fields */ }Expand description
A client for downloading and installing the Arm Toolchain for Embedded (ATfE).
Implementations
Sourceimpl ToolchainClient
impl ToolchainClient
pub const REPO_OWNER: &str = "arm"
pub const REPO_NAME: &str = "arm-toolchain"
pub const RELEASE_PREFIX: &str = "release-"
pub const RELEASE_SUFFIX: &str = "-ATfE"
pub const CURRENT_TOOLCHAIN_FILENAME: &str = "current.txt"
Sourcepub async fn using_data_dir() -> Result<Self, ToolchainError>
pub async fn using_data_dir() -> Result<Self, ToolchainError>
Creates a new toolchain client that installs to a platform-specific data directory.
For example, on macOS this is
~/Library/Application Support/dev.vexide.arm-toolchain/llvm-toolchains.
Sourcepub async fn new(
toolchains_path: impl Into<PathBuf>,
cache_path: impl Into<PathBuf>,
) -> Result<Self, ToolchainError>
pub async fn new( toolchains_path: impl Into<PathBuf>, cache_path: impl Into<PathBuf>, ) -> Result<Self, ToolchainError>
Creates a client that installs toolchains in the specified folder.
Sourcepub async fn latest_release(&self) -> Result<ToolchainRelease, ToolchainError>
pub async fn latest_release(&self) -> Result<ToolchainRelease, ToolchainError>
Fetches the latest release of the Arm Toolchain for Embedded (ATfE) from the ARM GitHub repository.
Sourcepub async fn get_release(
&self,
version: &ToolchainVersion,
) -> Result<ToolchainRelease, ToolchainError>
pub async fn get_release( &self, version: &ToolchainVersion, ) -> Result<ToolchainRelease, ToolchainError>
Fetches the given release of the Arm Toolchain for Embedded (ATfE) from the ARM GitHub repository.
Sourcepub fn install_path_for(&self, version: &ToolchainVersion) -> PathBuf
pub fn install_path_for(&self, version: &ToolchainVersion) -> PathBuf
Returns the path where the given toolchain version would be installed.
Sourcepub fn version_is_installed(&self, version: &ToolchainVersion) -> bool
pub fn version_is_installed(&self, version: &ToolchainVersion) -> bool
Checks if the specified toolchain version is already installed.
Sourcepub async fn download_and_install(
&self,
release: &ToolchainRelease,
asset: &Asset,
progress: Arc<dyn Fn(InstallState) + Send + Sync>,
cancel_token: CancellationToken,
) -> Result<PathBuf, ToolchainError>
pub async fn download_and_install( &self, release: &ToolchainRelease, asset: &Asset, progress: Arc<dyn Fn(InstallState) + Send + Sync>, cancel_token: CancellationToken, ) -> Result<PathBuf, ToolchainError>
Downloads the specified toolchain asset, verifies its checksum, extracts it, and installs it to the appropriate location.
The downloaded toolchain will be activated if there is no other active toolchain. Returns the path to the extracted toolchain directory.
Resuming downloads
This method will also handle resuming downloads if the file already exists and is partially downloaded. If the partially-downloaded file contains invalid bytes, a checksum error will be returned and the file will be deleted.
pub async fn installed_versions( &self, ) -> Result<Vec<ToolchainVersion>, ToolchainError>
Sourcepub async fn remove(
&self,
version: &ToolchainVersion,
progress: impl FnMut(RemoveProgress),
cancel_token: &CancellationToken,
) -> Result<(), ToolchainError>
pub async fn remove( &self, version: &ToolchainVersion, progress: impl FnMut(RemoveProgress), cancel_token: &CancellationToken, ) -> Result<(), ToolchainError>
Delete all files related to the given toolchain version.
Sourcepub async fn purge_cache(&self) -> Result<u64, ToolchainError>
pub async fn purge_cache(&self) -> Result<u64, ToolchainError>
Delete the cache directory, returning the number of bytes deleted.
Sourcepub fn active_toolchain(&self) -> Option<ToolchainVersion>
pub fn active_toolchain(&self) -> Option<ToolchainVersion>
Get the version of the active (default) toolchain.
Sourcepub async fn set_active_toolchain(
&self,
version: Option<ToolchainVersion>,
) -> Result<(), ToolchainError>
pub async fn set_active_toolchain( &self, version: Option<ToolchainVersion>, ) -> Result<(), ToolchainError>
Set the version of the active (default) toolchain.
This will write the given value to disk.
Sourcepub async fn toolchain(
&self,
version: &ToolchainVersion,
) -> Result<InstalledToolchain, ToolchainError>
pub async fn toolchain( &self, version: &ToolchainVersion, ) -> Result<InstalledToolchain, ToolchainError>
Returns a struct used to access paths of an installed toolchain.
This doesn’t check whether the specified version is actually installed, so make sure the paths exist before using them.